@@ -11,8 +11,7 @@ const HEALTHCHECK_API_URL: &str = "https://healthchecks.io/api/v1/";
 /// Typealias to prevent some repetitiveness in function definitions
 pub type ApiResult<T> = Result<T, HealthchecksApiError>;
 
-/// Struct that encapsulates the API key used to communicate with the healthchecks.io
-/// management API. Instances of this struct expose methods to query the API.
+/// Client type for communication with the healthchecks.io management API.
 #[derive(Clone)]
 pub struct ManageClient {
     pub(crate) api_key: String,
@@ -20,8 +19,10 @@ pub struct ManageClient {
     pub(crate) api_url: String,
 }
 
-/// Create an instance of [`ManageClient`] from a given API key. No validation
-/// is performed.
+/// Create an instance of [`ManageClient`] from a given API key and an
+/// optional custom user agent. Basic validation is performed but an
+/// invalid API key will go through this method and only fail when
+/// actually interacting with the API.
 pub fn get_client(
     api_key: String,
     user_agent: Option<String>,
@@ -29,6 +30,9 @@ pub fn get_client(
     get_client_with_url(api_key, user_agent, HEALTHCHECK_API_URL.to_owned())
 }
 
+/// Create an instance of [`ManageClient`] with a custom endpoint for the API.
+/// This is identical to [`get_client`](crate::manage::get_client) which uses it internally,
+/// but doesn't default to the hosted version at [healthchecks.io](https://healthchecks.io).
 pub fn get_client_with_url(
     api_key: String,
     user_agent: Option<String>,
@@ -51,6 +55,15 @@ pub fn get_client_with_url(
     }
 }
 
+/// When creating a new check, it's possible that the check already existed.
+/// This enum conveys that information.
+///
+/// See [`ManageClient::upsert_check`]
+pub enum UpsertResult {
+    Created,
+    Updated,
+}
+
 impl ManageClient {
     fn ureq_get(&self, path: String) -> Request {
         get(&path)
@@ -195,6 +208,22 @@ impl ManageClient {
 
     /// Creates a new check with the given [`NewCheck`] configuration.
     pub fn create_check(&self, check: NewCheck) -> ApiResult<Check> {
+        self.upsert_check(check).and_then(|(result, check)| {
+            if let UpsertResult::Created = result {
+                Ok(check)
+            } else {
+                Err(HealthchecksApiError::ExistingCheckMatched)
+            }
+        })
+    }
+
+    /// Creates a new check with the given [`NewCheck`] configuration.
+    ///
+    /// The [`unique`] field can be used to update existing checks, provided the checks can be found.
+    /// Otherwise, it will be created.
+    ///
+    /// [`unique`]: NewCheck::unique
+    pub fn upsert_check(&self, check: NewCheck) -> ApiResult<(UpsertResult, Check)> {
         let check_json = serde_json::to_value(check)?;
         let r = self.ureq_post(format!("{}/{}/", self.api_url, "checks"));
         match r
@@ -202,8 +231,8 @@ impl ManageClient {
             .send_json(check_json)
         {
             Ok(response) => match response.status() {
-                201 => Ok(response.into_json::<Check>()?),
-                200 => Err(HealthchecksApiError::ExistingCheckMatched),
+                201 => Ok((UpsertResult::Created, response.into_json::<Check>()?)),
+                200 => Ok((UpsertResult::Updated, response.into_json::<Check>()?)),
                 _ => Err(HealthchecksApiError::UnexpectedError(format!(
                     "Invalid result code: {}",
                     response.status()
