@@ -11,36 +11,37 @@ const HEALTHCHECK_PING_URL: &str = "https://hc-ping.com";
 // factor: https://blog.healthchecks.io/2020/01/fighting-packet-loss-with-curl/
 const MAX_RETRIES: i8 = 20;
 
-/// Struct that encapsulates the UUID that uniquely identifies your
-/// healthchecks.io endpoint. Instances of this expose methods to
-/// report status to healthchecks.io
+/// Client type for communication with the healthchecks.io ping API for a single
+/// check.
 pub struct PingClient {
     pub(crate) uuid: String,
     pub(crate) user_agent: String,
     pub(crate) ureq_agent: Agent,
+    pub(crate) api_url: String,
 }
 
-/// Create an instance of [`PingClient`] from a String UUID
-/// and a custom User-Agent header value. This method runs basic UUID validation and returns Err
+/// Create an instance of [`PingClient`] from the UUID of a check. This method runs basic UUID validation and
+/// returns an [`Err`](std::result::Result::Err) value wrapping [`HealthchecksConfigError`](crate::errors::HealthchecksConfigError)
 /// when the UUID is invalid.
-///
-/// # Usage
-///
-/// Starts a timer, sleeps for a second and then reports success.
-///
-/// ```rust
-/// use healthchecks::ping::get_client;
-///
-/// let client = get_client("2d0a34bd-854d-490e-be2c-1493f7053460").unwrap();
-/// ```
 pub fn get_client(uuid: &str) -> Result<PingClient, HealthchecksConfigError> {
+    get_client_with_url(uuid, HEALTHCHECK_PING_URL)
+}
+
+/// Same as [`get_client`](crate::ping::get_client), with the ability
+pub fn get_client_with_url(
+    uuid: &str,
+    api_url: &str,
+) -> Result<PingClient, HealthchecksConfigError> {
     if Uuid::parse_str(uuid).is_err() {
         Err(HealthchecksConfigError::InvalidUuid(uuid.to_string()))
+    } else if api_url.is_empty() {
+        Err(HealthchecksConfigError::EmptyApiUrl)
     } else {
         Ok(PingClient {
             uuid: uuid.to_owned(),
             user_agent: default_user_agent().to_owned(),
             ureq_agent: AgentBuilder::new().timeout(Duration::from_secs(5)).build(),
+            api_url: HEALTHCHECK_PING_URL.to_owned(),
         })
     }
 }
@@ -72,7 +73,7 @@ impl PingClient {
         let mut retries: i8 = 0;
         let request = self
             .ureq_agent
-            .get(&format!("{}/{}", HEALTHCHECK_PING_URL, self.uuid))
+            .get(&format!("{}/{}", self.api_url, self.uuid))
             .set("User-Agent", &self.user_agent);
         while retries < MAX_RETRIES {
             let resp = request.clone().call();
@@ -93,7 +94,7 @@ impl PingClient {
         let mut retries: i8 = 0;
         let request = self
             .ureq_agent
-            .get(&format!("{}/{}/fail", HEALTHCHECK_PING_URL, self.uuid))
+            .get(&format!("{}/{}/fail", self.api_url, self.uuid))
             .set("User-Agent", &self.user_agent);
         while retries < MAX_RETRIES {
             let resp = request.clone().call();
@@ -128,7 +129,7 @@ impl PingClient {
         let mut retries: i8 = 0;
         let request = self
             .ureq_agent
-            .post(&format!("{}/{}/fail", HEALTHCHECK_PING_URL, self.uuid))
+            .post(&format!("{}/{}/fail", self.api_url, self.uuid))
             .set("User-Agent", &self.user_agent);
         while retries < MAX_RETRIES {
             let resp = request.clone().send_string(data);
@@ -149,7 +150,7 @@ impl PingClient {
         let mut retries: i8 = 0;
         let request = self
             .ureq_agent
-            .get(&format!("{}/{}/start", HEALTHCHECK_PING_URL, self.uuid))
+            .get(&format!("{}/{}/start", self.api_url, self.uuid))
             .set("User-Agent", &self.user_agent);
         while retries < MAX_RETRIES {
             let resp = request.clone().call();
